@@ -1,5 +1,5 @@
 # UMLS::Interface 
-# (Last Updated $Id: Interface.pm,v 1.150 2016/07/11 16:36:48 btmcinnes Exp $)
+# (Last Updated $Id: Interface.pm,v 1.152 2016/10/18 16:13:28 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -421,7 +421,7 @@ my $pkg = "UMLS::Interface";
 
 use vars qw($VERSION);
 
-$VERSION = '1.49';
+$VERSION = '1.51';
 
 my $debug = 0;
 
@@ -1893,6 +1893,38 @@ sub findAncestors {
     return $hash;
 }
 
+=head3 findDescendents
+
+description:
+
+ function that returns all the ancestors of a concept 
+
+input:   
+
+ $concept  <- the concept
+
+output:
+
+ %hash <- reference to hash containing ancestors
+
+example:
+
+ use UMLS::Interface;
+ my $umls = UMLS::Interface->new(); 
+ my $concept = "C0018563";
+ my $hash =  $umls->findDescendents($concept); 
+
+=cut
+sub findDescendants {
+
+    my $self = shift;
+    my $concept = shift;
+    
+    my $hash = $pathfinder->_findDescendants($concept);
+    
+    return $hash;
+}
+
 =head3 findShortestPathLength
 
 description:
