@@ -1,5 +1,5 @@
 # UMLS::Interface::PathFinder
-# (Last Updated $Id: PathFinder.pm,v 1.67 2015/12/29 17:51:41 btmcinnes Exp $)
+# (Last Updated $Id: PathFinder.pm,v 1.68 2016/10/18 16:10:06 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -2079,7 +2079,6 @@ sub _findAncestors {
     if(!defined $self || !ref $self) {
 	$errorhandler->_error($pkg, $function, "", 2);
     }
-
     my @paths = $self->_pathsToRoot($concept);
     
     my %ancestors = (); 
@@ -2947,7 +2946,7 @@ sub _findNumberOfCloserConcepts {
 	    #  check if concept has already in the path
 	    if($series1=~/$parent1/) { next; }
 	    if($parent1 eq $c1)      { next; }
-	    unshift @stack1, $parent1;
+	    unshift@stack1, $parent1;
 	    unshift @paths1, \@intermediate1;
 	    unshift @relations1, "PAR";
 	    unshift @directions1, $dchange1;
@@ -3033,6 +3032,85 @@ sub _findNumberOfCloserConcepts {
     return $counter;
 }
 
+sub _findDescendants { 
+    my $self = shift; 
+    my $concept = shift; 
+    
+    my $function = "_findDescendants";
+    &_debug($function);
+    
+    #  check self
+    if(!defined $self || !ref $self) {
+	$errorhandler->_error($pkg, $function, "", 2);
+    }
+    #  check parameter exists
+    if(!defined $concept) { 
+	$errorhandler->_error($pkg, $function, "Error with input variable \$concept1.", 4);
+    }
+    #  check if valid concept
+    if(! ($errorhandler->_validCui($concept)) ) {
+	$errorhandler->_error($pkg, $function, "Concept ($concept) in not valid.", 6);
+    }    
+    
+    my %decendents = (); 
+    
+    my $children = $cuifinder->_getChildren($concept); 
+
+    foreach my $child (@{$children}) {
+	my @array = (); 
+	push @array, $root;
+	my $path  = \@array;
+
+	&_descendentSearch($child, $path, \%decendents, *F);
+	
+    }
+    
+    return \%decendents; 
+}
+
+sub _descendentSearch
+{
+    my $concept = shift;
+    my $array   = shift;
+    my $decendents = shift; 
+    local(*F)   = shift;
+
+    #  set the new path
+    my @path = @{$array};
+    push @path, $concept;
+    
+    my $series = join " ", @path;
+    
+    #  print information into the file if debugpath option is set
+    if($option_debugpath) { print F "$concept\t$series\n"; }
+    
+    #  get all the children
+    my $children = $cuifinder->_getChildren($concept);
+
+    #  search through the children
+    foreach my $child (@{$children}) {
+	
+	#  check if child cui has already in the path
+	my $flag = 0;
+	foreach my $cui (@path) {
+	    if($cui eq $child) { 
+		$flag = 1; 
+	    }
+	}
+
+	#  if it isn't continue on with the depth first search
+	if($flag == 0) {
+	    #  check that the concept is not a forbidden concept
+	    if($cuifinder->_forbiddenConcept($child) == 1) { return; }
+
+	    #  store the decendents
+	    $decendents->{$child} = 1; 
+	
+	    &_descendentSearch($child, \@path, $decendents, *F);
+	}
+    }
+}
+
 1;
 
 __END__
