@@ -191,9 +191,6 @@ if(defined $opt_username) {
 if(defined $opt_debug) {
     $option_hash{"debug"} = $opt_debug;
 }
-if(defined $opt_driver) {
-    $option_hash{"driver"}   = $opt_driver;
-}
 if(defined $opt_database) {
     $option_hash{"database"} = $opt_database;
 }
@@ -323,7 +320,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getChildren.pl,v 1.17 2011/08/29 16:37:03 btmcinnes Exp $';
+    print '$Id: getChildren.pl,v 1.18 2016/01/07 22:49:33 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
